<?php

declare(strict_types=1);

use FiloBlu\OrderAdditionalData\Model\Plugin\OrderPlace;
use Magento\Framework\App\Bootstrap;
use Magento\Framework\App\ResourceConnection;
use Magento\Sales\Api\OrderRepositoryInterface;

require __DIR__ . '/../../../../../app/bootstrap.php';
$params = $_SERVER;
$bootstrap = Bootstrap::create(BP, $params);

$objectManager = $bootstrap->getObjectManager();
$connection = $objectManager->get(ResourceConnection::class)->getConnection();

/** @var \Magento\Sales\Api\OrderRepositoryInterface $orderRepository */
$orderRepository = $objectManager->get(OrderRepositoryInterface::class);

$ordersToFix = $connection->fetchAssoc(
    'SELECT entity_id,increment_id FROM sales_order WHERE shipping_amount  = 0 and fbnetsuite_theoric_shipping_amount = 0'
);

foreach ($ordersToFix as $orderId => $data) {
    /** @var \FiloBlu\OrderAdditionalData\Model\Plugin\OrderPlace $orderPlacePlugin */
    $orderPlacePlugin = $objectManager->create(OrderPlace::class);
    $order = $orderRepository->get($orderId);
    $value = $orderPlacePlugin->simulateShippingAmount($order);

    echo "Updating {$data['increment_id']} ($orderId) : Theoric Shipping Amount => {$value->getValue()}\n";

    $connection->update('sales_order', [
        'fbnetsuite_base_theoric_shipping_amount' => $value->getValue(),
        'fbnetsuite_theoric_shipping_amount' => $value->getValue(),
    ], $connection->quoteInto('entity_id = ?', $orderId));


    $oad = $connection->fetchRow("SELECT * FROM sales_oad_order WHERE order_id = $orderId");

    if ($oad && isset($oad['additional_data'])) {
        $additionalData = json_decode($oad['additional_data'], true);
        $additionalData['theoric_shipping_amount'] = ['value' => $value->getValue()];
        $connection->update(
            'sales_oad_order',
            ['additional_data' => json_encode($additionalData)],
            $connection->quoteInto('order_id = ?', $orderId)
        );
    }
}
